@@ -9,6 +9,8 @@
 
 #include <QObject>
 
+#include "kwin_interface.h"
+
 class ShowDesktop : public QObject
 {
     Q_OBJECT
@@ -22,10 +24,13 @@ public:
     bool showingDesktop() const;
     void setShowingDesktop(bool showingDesktop);
 
-    Q_INVOKABLE void minimizeAll();
+    Q_INVOKABLE void toggleDesktop();
 
 Q_SIGNALS:
     void showingDesktopChanged(bool showingDesktop);
+
+private:
+    OrgKdeKWinInterface *m_interface;
 };
 
 #endif // SHOWDESKTOP_HEADER
