@@ -11,8 +11,9 @@
 
 #include "logging.h"
 
-DevicesModel::DevicesModel(QObject *parent)
+DevicesModel::DevicesModel(const QByteArray &kind, QObject *parent)
     : QAbstractListModel(parent)
+    , m_kind(kind)
 {
     m_deviceManager = new QDBusInterface(QStringLiteral("org.kde.KWin"),
                                          QStringLiteral("/org/kde/KWin/InputDevice"),
@@ -39,7 +40,6 @@ DevicesModel::DevicesModel(QObject *parent)
 void DevicesModel::resetModel()
 {
     beginResetModel();
-    qDeleteAll(m_devices);
     m_devices.clear();
 
     QStringList devicesSysNames;
@@ -67,19 +67,19 @@ QVariant DevicesModel::data(const QModelIndex &index, int role) const
     case Qt::DisplayRole:
         return m_devices.at(index.row())->name();
     case Qt::UserRole:
-        return QVariant::fromValue<QObject *>(m_devices.at(index.row()));
+        return QVariant::fromValue<QObject *>(m_devices.at(index.row()).get());
     }
     return {};
 }
 
 int DevicesModel::rowCount(const QModelIndex &parent) const
 {
-    return parent.isValid() ? 0 : m_devices.count();
+    return parent.isValid() ? 0 : m_devices.size();
 }
 
 void DevicesModel::onDeviceAdded(const QString &sysName)
 {
-    if (std::any_of(m_devices.constBegin(), m_devices.constEnd(), [sysName](InputDevice *t) {
+    if (std::any_of(m_devices.cbegin(), m_devices.cend(), [sysName](auto &t) {
             return t->sysName() == sysName;
         })) {
         return;
@@ -95,16 +95,16 @@ void DevicesModel::addDevice(const QString &sysName, bool tellModel)
                                QStringLiteral("org.kde.KWin.InputDevice"),
                                QDBusConnection::sessionBus(),
                                this);
-    QVariant reply = deviceIface.property("tabletTool");
+    QVariant reply = deviceIface.property(m_kind);
     if (reply.isValid() && reply.toBool()) {
-        InputDevice *dev = new InputDevice(sysName);
-        connect(dev, &InputDevice::needsSaveChanged, this, &DevicesModel::needsSaveChanged);
+        auto dev = std::make_unique<InputDevice>(sysName, this);
+        connect(dev.get(), &InputDevice::needsSaveChanged, this, &DevicesModel::needsSaveChanged);
 
         if (tellModel) {
-            beginInsertRows({}, m_devices.count(), m_devices.count());
+            beginInsertRows({}, m_devices.size(), m_devices.size());
         }
-        m_devices.append(dev);
         qCDebug(KCM_TABLET).nospace() << "Device connected: " << dev->name() << " (" << dev->sysName() << ")";
+        m_devices.push_back(std::move(dev));
         if (tellModel) {
             endInsertRows();
         }
@@ -113,26 +113,30 @@ void DevicesModel::addDevice(const QString &sysName, bool tellModel)
 
 void DevicesModel::onDeviceRemoved(const QString &sysName)
 {
-    QVector<InputDevice *>::const_iterator it = std::find_if(m_devices.constBegin(), m_devices.constEnd(), [sysName](InputDevice *t) {
+    auto it = std::find_if(m_devices.cbegin(), m_devices.cend(), [sysName](auto &t) {
         return t->sysName() == sysName;
     });
     if (it == m_devices.cend()) {
         return;
     }
 
-    InputDevice *dev = static_cast<InputDevice *>(*it);
+    InputDevice *dev = static_cast<InputDevice *>(it->get());
     qCDebug(KCM_TABLET).nospace() << "Device disconnected: " << dev->name() << " (" << dev->sysName() << ")";
 
-    int index = m_devices.indexOf(*it);
+    int index = std::distance(m_devices.cbegin(), it);
 
     beginRemoveRows({}, index, index);
-    m_devices.removeAt(index);
-    endInsertRows();
+    m_devices.erase(m_devices.cbegin() + index);
+    endRemoveRows();
 }
 
 InputDevice *DevicesModel::deviceAt(int row) const
 {
-    return m_devices.value(row, nullptr);
+    if (row == -1) {
+        return nullptr;
+    }
+
+    return m_devices.at(row).get();
 }
 
 QHash<int, QByteArray> DevicesModel::roleNames() const
@@ -144,35 +148,35 @@ QHash<int, QByteArray> DevicesModel::roleNames() const
 
 void DevicesModel::defaults()
 {
-    for (auto device : qAsConst(m_devices)) {
+    for (auto &device : qAsConst(m_devices)) {
         device->defaults();
     }
 }
 
 void DevicesModel::load()
 {
-    for (auto device : qAsConst(m_devices)) {
+    for (auto &device : qAsConst(m_devices)) {
         device->load();
     }
 }
 
 void DevicesModel::save()
 {
-    for (auto device : qAsConst(m_devices)) {
+    for (auto &device : qAsConst(m_devices)) {
         device->save();
     }
 }
 
 bool DevicesModel::isDefaults() const
 {
-    return std::all_of(m_devices.constBegin(), m_devices.constEnd(), [](InputDevice *dev) {
+    return std::all_of(m_devices.cbegin(), m_devices.cend(), [](auto &dev) {
         return dev->isDefaults();
     });
 }
 
 bool DevicesModel::isSaveNeeded() const
 {
-    return std::any_of(m_devices.constBegin(), m_devices.constEnd(), [](InputDevice *dev) {
+    return std::any_of(m_devices.cbegin(), m_devices.cend(), [](auto &dev) {
         return dev->isSaveNeeded();
     });
 }
