@@ -7,20 +7,21 @@
 #ifndef PROPERTYINFO_H
 #define PROPERTYINFO_H
 
-#include <QSharedPointer>
+#include <QVersionNumber>
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QX11Info>
 #else
 #include <QtGui/private/qtx11extras_p.h>
 #endif
 #include <X11/Xdefs.h>
+#include <memory>
 
 void XDeleter(void *p);
 
 struct PropertyInfo {
     Atom type;
     int format;
-    QSharedPointer<unsigned char> data;
+    std::shared_ptr<unsigned char> data;
     unsigned long nitems;
 
     float *f;
